@@ -1,10 +1,11 @@
 import typer
-from timecli.commands import oracle
+from commands import oracle, pomodoro
 
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 app = typer.Typer()
 app.add_typer(oracle.app, name="oracle")
+app.add_typer(pomodoro.app, name="pomodoro")
 
 
 def call_version(value: bool):
